<?
    #
    # define the default values here
    #
    $default_width  = 300;
    $default_height = 200;

    $default_title  = "";
    $default_side_label = "";
    $default_bottom_label = "";

    $font = 1;

    $graph_border = 3;

    #
    # set some default values for those items that
    # were not passed in
    #
    $width  = (empty($width)?$default_width:$width);
    $height = (empty($height)?$default_height:$height);

    $title  = (empty($title)?$default_title:$title);
    $side_label = (empty($side_label)?$default_side_label:$side_label);
    $bottom_label = (empty($bottom_label)?$default_bottom_label:$bottom_label);

    $names = @explode(",",$labels);
    $values = @explode(",",$results);

    if(count($names) == 1 && empty($names[0])) {
        $names = "";
    }
    ######################################################################

    #
    # calculate some information before we begin
    #
    $num_results = count($values);

    # find the max value
    $max_value = @max($values);
    $max_value = ($max_value < 4 ? 4 : $max_value );

    # round the max in a good fasion to give an appropriate max
    if($max_value <= 10) {
        # if it's less than 10 lets just make it an even number
        if($max_value % 2) {
            $max_value += 1; # it's odd so add 1 to it
        }
    } else {
        # it's over ten so we will just incriment the number to the nearest 10th of a hundred
        $max_value = (((int)($max_value / 10)) * 10) + 10;
    }
    

    #######################################################################

    #
    # start drawing the image
    #
    $graph_area = array(0 + $graph_border,
                        0 + $graph_border,
                        $width - $graph_border - 1,
                        $height - $graph_border - 1);

    $graph = ImageCreate($width, $height);

    $black  = ImageColorAllocate($graph,0,0,0);
    $red    = ImageColorAllocate($graph,255,0,0);
    $green  = ImageColorAllocate($graph,0,255,0);
    $blue   = ImageColorAllocate($graph,0,0,255);
    $ltgray = ImageColorAllocate($graph,180,180,180);
    $white  = ImageColorAllocate($graph,255,255,255);

    # we will setup 4 colors to use in the graph bars
    $color_1 = $red;
    $color_2 = $black;
    $color_3 = $green;
    $color_4 = $blue;

    ImageFilledRectangle($graph, 0, 0, $width, $height, $white);

    # get the dimensions of the font we are using
    $font_width  = ImageFontWidth($font);
    $font_height = ImageFontHeight($font);

    # draw the title
    if(!empty($title)) {
        $title_length = strlen($title);
        $title_width  = $title_length * $font_width;
        $title_height = $font_height;

        $title_offset = (int)(($width - $title_width) / 2);

        ImageString($graph,$font,$title_offset, $graph_area[1], $title, $black);

        # adjust the graph_area variable to take into accoun the space the title
        # is using up on the image
        $graph_area[1] += $title_height + $graph_border;
    }

    # draw the side label of the graph
    if(!empty($side_label)) {
        $side_label_length = strlen($side_label);
        $side_label_width = $font_height; # because we are drawing it vertically
        $side_label_height = $side_label_length * $font_width;

        $side_label_offset = (int)(($height - $side_label_height) / 2);

        ImageStringUp($graph,$font,$graph_area[0],$side_label_offset + $side_label_height,$side_label,$black);

        # now update the graph_area to relect the space side_label is using
        $graph_area[0] += $side_label_width + $graph_border;
    }

    if(!empty($bottom_label)) {
        $bottom_label_length = strlen($bottom_label);
        $bottom_label_width = $bottom_label_length * $font_width;
        $bottom_label_height = $font_height;

        $bottom_label_offset = (int)((($graph_area[2] - $graph_area[0]) - $bottom_label_width) / 2);

        ImageString($graph,$font,$graph_area[0] + $bottom_label_offset, $graph_area[3] - $bottom_label_height, $bottom_label, $black);

        # now update the graph_area to account for the space bottom_label used
        $graph_area[3] -= ($bottom_label_height + $graph_border);
    }

    # this is going to get funky :(
    # add in the space to be used by the value key so we can
    # calculate the correct width the column labels have to use
    # then after we are done with the column labels we have to take it back to
    # properly print in the value markers
    $max_length = strlen(sprintf("%d",$max_value));
    $max_width  = $max_length * $font_width;
    $graph_area[0] += $max_width + $graph_border;


    #
    # draw the column labels here
    #
    $graph_area_width = $graph_area[2] - $graph_area[0];
    $column_width = $graph_area_width / $num_results;
    $column_char_length = (int)($column_width / $font_width);

    if(!empty($names)) {
        for($i = 0; $i < $num_results; $i++) {
            $clabel = $names[$i];
            $clabel = substr($clabel,0,$column_char_length);
            $clabel_length = strlen($clabel);
            $clabel_width = $font_width * $clabel_length;
            $clabel_offset = (int)(($column_width - $clabel_width) / 2);
    
            ImageString($graph,$font,
                    ($graph_area[0] + ($column_width * $i) + $clabel_offset),
                    ($graph_area[3] - $font_height),
                    $clabel, $black);
        }

        # take away space used by column labels
        $graph_area[3] -= ($font_height + $graph_border);
    }

    # now undo the change we did for the value marker
    $graph_area[0] -= ($max_width + $graph_border);

    # now draw our value markers
    $marker_increment = (int)($max_value / 4);
    $marker_pixel_increment = (int)(($graph_area[3] - $graph_area[1]) / 4);
    $marker_font_offset = (int)($font_height / 2);

    for($i = 0; $i < 5; $i ++) {
        $marker_val = $i * $marker_increment;
        $marker_val = sprintf("%d",$marker_val);
        $marker_val_length = strlen($marker_val);
        $marker_val_width = $marker_val_length * $font_width;
        $marker_offset = $i * $marker_pixel_increment;

        ImageString($graph,$font,($graph_area[0] + $max_width) - $marker_val_width,
                                 ($graph_area[3] - $marker_offset) - $marker_font_offset,
                                  $marker_val, $black);
    }

    # update the graph_area to take into account the markers
    $graph_area[0] += $max_width + $graph_border;

    # draw the bounding box of the graph area
    ImageRectangle($graph,$graph_area[0],$graph_area[1],$graph_area[2],$graph_area[3],$ltgray);

    # draw the horizontal markers
    for($i = 1; $i < 4; $i++) {
        $vertical_bar_pos = (int)($graph_area[3] - ($i * $marker_pixel_increment));
        ImageLine($graph,
                  ($graph_area[0]), ($vertical_bar_pos),
                  ($graph_area[2]), ($vertical_bar_pos),
                  $ltgray);
    }

    # now draw each bar in the results
    $bar_width = (int)($column_width * 0.75);
    $bar_width = ($bar_width < 5 ? $column_width : $bar_width);
    $bar_offset = (int)(($column_width - $bar_width) / 2);
    $graph_area_height = (int)($graph_area[3] - $graph_area[1]);
    $bar_pixel_increment = (int)($graph_area_height / $max_value);
    for($i = 0; $i < $num_results; $i++) {
        $bar_color = (($i % 4) + 1);
        $bar_color = "color_" . $bar_color;
        $bar_height = (int)($bar_pixel_increment * $values[$i]);

        ImageFilledRectangle($graph,
             ($graph_area[0] + ($column_width * $i) + $bar_offset),
             ($graph_area[3] - $bar_height),
             ($graph_area[0] + ($column_width * $i) + $bar_offset + $bar_width),
             ($graph_area[3]),
             $$bar_color);
    }

    # tada! we are done!

    #
    # Show me the image!
    #
    header("Content-type: image/gif");
    ImageGIF($graph);
    ImageDestroy($graph);
 ?>
