/*
 * File: survey.sql 
 *
 * Description:
 *     These are the tables for the survey function 
 *
 * Creator: Allen mcGrath (amcgrath@greatbridge.com) 
 * Created: 10/04/2000
 *
 * Change Log:
 *     Allen McGrath <allen@greatbridge.com>
 *         - Initial file creation
 */

/*
 * Table: survey, SURVEY_QUESTION, SURVEY_ANSWER, SURVEY_RESPONSE
 *
 * Description: 
 *     SURVEY: contains the owner of the survey and project it attached to. 
 *     SURVEY_QUESTION: holds the survey's questions.
 *     SURVEY_ANSWER: holds the survey's possible answer choices.
 *     SURVEY_RESPONSE: holds member responses to the survey.
 *
 * Field Description:
 *
 */
CREATE SEQUENCE survey_survey_id_seq;
CREATE SEQUENCE survey_quest_id_seq;
CREATE SEQUENCE survey_answ_id_seq;
CREATE SEQUENCE survey_resp_id_seq;
CREATE TABLE survey (
survey_id   int4 unique not null default nextval('survey_survey_id_seq'),
member_id   int4 not null references member(member_id),
project_id  int4,
create_date date default now(),
survey_title varchar(100),
active      bool default 't',
temp_id	    varchar(32),
primary key (survey_id)
);

CREATE TABLE survey_question (
question_id   int4 not null unique default nextval('survey_quest_id_seq'),
survey_id     int4 not null references survey(survey_id),
temp_id       varchar(32),
question      varchar(500) not null,
primary key (survey_id, question_id)
);

CREATE TABLE survey_answer (
answer_id    int4 not null unique default nextval('survey_answ_id_seq'),
question_id  int4 not null references survey_question(question_id),
temp_id      varchar(32),
answer	     varchar(500) not null,
primary key (answer_id)
);

CREATE TABLE survey_response (
response_id  int4 not null unique default nextval('survey_resp_id_seq'),
survey_id    int4 not null references survey(survey_id),
question_id  int4 not null references survey_question(question_id),
member_id    int4 not null,
answer_id    int4 not null references survey_answer(answer_id),
primary key (response_id)
);
