/*
 * File: taskmng.sql
 *
 * Description:
 *     This files contains all the tables used for the task manager.
 *
 * Creator: Chris Ryan <chris@greatbridge.com>
 * Created: 09/28/2000
 *
 * Change Log:
 *     Chris Ryan <chris@greatbridge.com> 09/28/2000
 *         - Initial file creation
 *     Chris Ryan <chris@greatbridge.com> 10/25/2000
 *         - Added some additional comments
 */

/*
 * Table: task
 *
 * Description:
 *     Tasks for a project
 *
 * Field Description:
 * task_id       the is of this task (primary key)
 * project_id    the project this task belongs to
 * task_name     the name of this task
 * assigned_to   the member this task is assigned to
 * start_date    the date this task is to start work on
 * end_date      the date this task is to be completed by
 * hours         the number of hours this task is supposed to take
 * percent_done  the percentage of completion for this task
 * status_id     the status of this task
 * priority      the priority of this task
 * comments      comments about this task
 * created_by    the member who created this task
 * date_created  the date this task was created
 */
CREATE SEQUENCE task_task_id_seq;
CREATE TABLE task (
    task_id      int4 not null unique default nextval('task_task_id_seq'),
    project_id   int4 not null references project (project_id),
    task_name    varchar(64) not null,
    assigned_to  int4,
    start_date   timestamp not null default now(),
    end_date     timestamp not null default now(),
    hours        int4,
    percent_done int4 not null default 0 CHECK (percent_done >= 0 and percent_done <= 100),
    status_id    int4 references category (cat_id),
    priority     int4 not null,
    comments     text,
    created_by   int4 not null references member (member_id),
    date_created timestamp not null default now(),
    version_id   int4,
    primary key(task_id)
);

/*
 * Table: task_dependency
 *
 * Description:
 *     Dependencies that this task has on other tasks
 *
 * Field Description:
 * task_id     the id of the task this for the dependency
 * dependency  the task this task is dependant upon
 *
 * Primary key: join on task_id, dependency
 */
CREATE TABLE task_dependency (
    task_id    int4 not null references task (task_id),
    dependency int4 not null references task (task_id),
    primary key (task_id, dependency)
);

